--TABLE CREATE
CREATE TABLE IF NOT EXISTS report_canevas (
        canevas_id serial NOT NULL,
        canevas_name varchar NOT NULL,
        canevas_description varchar,
        canevas_interval interval,
        canevas_date_nextgeneration timestamp,
        canevas_parameter json,
        CONSTRAINT report_canevas_PrimaryKey PRIMARY KEY (canevas_id)
        );

CREATE TABLE IF NOT EXISTS report_block (
        block_id serial NOT NULL,
        block_name varchar,
        block_controller varchar,
        block_default_parameter json,
        CONSTRAINT report_block_PrimaryKey PRIMARY KEY (block_id)
        );

ALTER TABLE report_block
ADD CONSTRAINT block_name_unique UNIQUE (block_name);

CREATE TABLE IF NOT EXISTS report_include_block (
        include_id serial NOT NULL,
        include_block_id integer,
        include_canevas_id integer,
        include_position integer,
        include_parameter json,
        CONSTRAINT report_include_block_PrimaryKey PRIMARY KEY (include_id),
        CONSTRAINT report_include_block_ForKey_include_block_id FOREIGN KEY (include_block_id)
        REFERENCES report_block(block_id) MATCH SIMPLE ON UPDATE NO ACTION ON DELETE NO ACTION,
        CONSTRAINT report_include_block_ForKey_include_canevas_id FOREIGN KEY (include_canevas_id)
        REFERENCES report_canevas(canevas_id) MATCH SIMPLE ON UPDATE NO ACTION ON DELETE NO ACTION
        );


CREATE TABLE IF NOT EXISTS report (
        id serial NOT NULL,
        name varchar,
        date_generate timestamp DEFAULT NOW(),
        path_html varchar,
        path_pdf varchar,
        canevas_id integer,
        report_date_start timestamp,
        report_date_end timestamp,
        CONSTRAINT report_PrimaryKey PRIMARY KEY (id),
        CONSTRAINT report_ForKey_canevas_id FOREIGN KEY (canevas_id)
        REFERENCES report_canevas(canevas_id) MATCH SIMPLE ON UPDATE NO ACTION ON DELETE NO ACTION
        );

CREATE TABLE IF NOT EXISTS report_send_users (
        send_canevas_id integer,
        send_user_id integer,
	canevas_user_share BOOLEAN default FALSE,
	canevas_user_writing BOOLEAN default FALSE,
        CONSTRAINT report_send_users_ForKey_send_canevas_id FOREIGN KEY (send_canevas_id)
        REFERENCES report_canevas(canevas_id) MATCH SIMPLE ON UPDATE NO ACTION ON DELETE NO ACTION,
        CONSTRAINT report_send_users_ForKey_send_user_id FOREIGN KEY (send_user_id)
        REFERENCES esia_users(user_id) MATCH SIMPLE ON UPDATE NO ACTION ON DELETE NO ACTION,
	CONSTRAINT "report_primaryKey" PRIMARY KEY(send_canevas_id, send_user_id)
        );

--DATA INSERT 
INSERT INTO esia_configuration(
            config_key, config_value, config_description, config_type, config_visibility)
    VALUES ('REPORT_MAIL_SMTP',NULL,'','varchar',FALSE)
ON CONFLICT (config_key) DO NOTHING;

INSERT INTO esia_configuration(
            config_key, config_value, config_description, config_type, config_visibility)
    VALUES ('REPORT_MAIL_SMTP_PORT','465','','integer',FALSE)
ON CONFLICT (config_key) DO NOTHING;

INSERT INTO esia_configuration(
            config_key, config_value, config_description, config_type, config_visibility)
    VALUES ('REPORT_MAIL_SSL','on','','boolean',FALSE)
ON CONFLICT (config_key) DO NOTHING;


INSERT INTO esia_configuration(config_key, config_value, config_description,config_type,config_visibility)
VALUES ('REPORT_MAIL_FROM', NULL, '','varchar',FALSE)
ON CONFLICT (config_key) DO NOTHING;

INSERT INTO esia_configuration(
            config_key, config_value, config_description, config_type, config_visibility)
    VALUES ('REPORT_MAIL_USER',NULL,'','varchar',FALSE)
ON CONFLICT (config_key) DO NOTHING;

INSERT INTO esia_configuration(
            config_key, config_value, config_description, config_type, config_visibility)
    VALUES ('REPORT_MAIL_PASSWORD',NULL,'','varchar',FALSE)
ON CONFLICT (config_key) DO NOTHING;

 INSERT INTO esia_privileges(
           privilege_id, privilege_name, privilege_site, privilege_description)
   VALUES (DEFAULT, 'report_canevas', '1', 'Gestion des canevas')
ON CONFLICT (privilege_name) DO NOTHING;

 INSERT INTO esia_privileges(
           privilege_id, privilege_name, privilege_site, privilege_description)
   VALUES (DEFAULT, 'report_administration_mail', '1', 'Gestion des mails')
ON CONFLICT (privilege_name) DO NOTHING;


-- REPORT BLOCK
INSERT INTO report_block(
            block_name, block_controller, block_default_parameter)
    VALUES ('REPORT_INCIDENT_GROUP_NODE', 'incident.php', '{"title":{"text":"Incident","style":{"text-align":"left", "font-size":"15px", "color":"#575759"}},"description":{"text":"Voici la description d''un incident","style":{"text-align":"left", "margin":"auto", "font-size":"12px"}},"table":{"class":"arraytop","style":"width:60%; height:60%; margin:auto; border-spacing: 10px 10px;"},"td":{"class":"classtd","style":"font-size:50px"},"type":"groupenoeud","affiche_duree":true,"affiche_ip":true,"affiche_groupNoeud":true,"affiche_message":true,"groupnodeid":[]}')
ON CONFLICT (block_name) DO NOTHING;

INSERT INTO report_block(
            block_name, block_controller, block_default_parameter)
VALUES ('REPORT_AVAILABILITY_GROUP_NODE', 'availability.php', '{"title":{"text":"Disponibilite","style":{"text-align":"left", "font-size":"15px", "color":"#575759"}},"description":{"text":"Voici la description disponibilité d''un groupe de noeud","style":{"text-align":"left", "margin":"auto", "font-size":"12px"}},"table":{"class":"arraytop","style":"width:60%; height:60%; margin:auto; border-spacing: 10px 10px;"},"td":{"class":"classtd","style":"font-size:50px"},"SeuilWarning":"80","SeuilCritical":"70","forme":"graph","type":"groupenoeud","groupnodeid":[]}')
ON CONFLICT (block_name) DO NOTHING;

INSERT INTO report_block(
            block_name, block_controller, block_default_parameter)
    VALUES ('REPORT_USERESOURCE_GROUP_NODE', 'useResources.php', '{"title":{"text":"Utilisation des ressources","style":{"text-align":"left", "font-size":"15px", "color":"#575759"}},"description":{"text":"Voici la description de l''utilsation des ressources","style":{"text-align":"left", "margin":"auto", "font-size":"12px"}},"table":{"class":"arraytop","style":"width:60%; height:60%; margin:auto; border-spacing: 10px 10px;"},"td":{"class":"classtd","style":"font-size:50px"},"SeuilWarningCpu":"70","SeuilCriticalCpu":"80","SeuilWarningRam":"70","SeuilCriticalRam":"80","SeuilWarningStorage":"70","SeuilCriticalStorage":"80","type":"groupenoeud","affiche_ram":true,"affiche_stockage":true,"affiche_description":true,"affiche_ip":true,"affiche_cpu":true,"groupnodeid":[]}')
ON CONFLICT (block_name) DO NOTHING;

INSERT INTO report_block(
            block_name, block_controller, block_default_parameter)
    VALUES ('REPORT_USERESOURCE_NODE', 'useResources.php', '{"title":{"text":"Utilisation des ressources","style":{"text-align":"left", "font-size":"15px", "color":"#575759"}},"description":{"text":"Voici la description dl''utilsation des ressources","style":{"text-align":"left", "margin":"auto", "font-size":"12px"}},"table":{"class":"arraytop","style":"width:60%; height:60%; margin:auto; border-spacing: 10px 10px;"},"td":{"class":"classtd","style":"font-size:50px"},"SeuilWarningCpu":"70","SeuilCriticalCpu":"80","SeuilWarningRam":"70","SeuilCriticalRam":"80","SeuilWarningStorage":"70","SeuilCriticalStorage":"80","type":"noeud","affiche_ram":true,"affiche_stockage":true,"affiche_description":true,"affiche_ip":true,"affiche_groupNoeud":true,"affiche_cpu":true,"nodeid":[]}')
ON CONFLICT (block_name) DO NOTHING;

INSERT INTO public.report_block(
            block_id, block_name, block_controller, block_default_parameter)
    VALUES (DEFAULT,'REPORT_CONNECTIVITY','connectivity.php','{"title":{"text":"Disponibilité","style":{"text-align":"left", "font-size":"15px", "color":"#575759"}},"description":{"text":"Voici la description de la connectivité d''un groupe de noeud","style":{"text-align":"left", "margin":"auto", "font-size":"12px"}},"table":{"class":"arraytop","style":"width:60%; height:60%; margin:auto; border-spacing: 10px 10px;"},"td":{"class":"classtd","style":"font-size:50px"},"warningThreshold":"95","criticalThreshold":"90","forme":"graph","type":"noeud","groupid":0,"calcunknown":"none","calcwarning":"on","calccritical":"on","form":"graphCol"}')
ON CONFLICT (block_name) DO NOTHING;

INSERT INTO public.report_block(
            block_id, block_name, block_controller, block_default_parameter)
    VALUES (DEFAULT,'REPORT_STORAGE','storage.php','{"title":{"text":"Espace de stockage","style":{"text-align":"left", "font-size":"15px", "color":"#575759"}},"description":{"text":"Voici la description de l''utilisation de l''espace de stockage","style":{"text-align":"left", "margin":"auto", "font-size":"12px"}},"table":{"class":"arraytop","style":"width:60%; height:60%; margin:auto; border-spacing: 10px 10px;"},"td":{"class":"classtd","style":"font-size:50px"},"warningThreshold":"80","criticalThreshold":"70","forme":"graph","type":"noeud","groupid":0,"form":"gauge","criticalThreshold":"90","warningThreshold":"80"}')
ON CONFLICT (block_name) DO NOTHING;

INSERT INTO public.report_block(
            block_id, block_name, block_controller, block_default_parameter)
    VALUES (DEFAULT,'HARDWARE_INCIDENT','hardware_incident.php','{"title":{"text":"Incidents matériels","style":{"text-align":"left", "font-size":"15px", "color":"#575759"}},"description":{"text":"Voici la description du bloc incident","style":{"text-align":"left", "margin":"auto", "font-size":"12px"}},"table":{"class":"arraytop","style":"width:60%; height:60%; margin:auto; border-spacing: 10px 10px;"},"td":{"class":"classtd","style":"font-size:50px"},"warningThreshold":"80","criticalThreshold":"70","forme":"graph","type":"noeud","groupid":0,"form":null,"calcunknown":"none","calcwarning":"on","calccritical":"on","tag":"RAID,HEALTH,DISK"}')
ON CONFLICT (block_name) DO NOTHING;

INSERT INTO report_block(block_name, block_controller, block_default_parameter)
SELECT 'REPORT_VALUE_SERVICE_NODE', 'value_service.php', '{"title":{"text":"Valeur de services","style":{"text-align":"left", "font-size":"15px", "color":"#575759"}},"description":{"text":"Voici la valeur des services","style":{"text-align":"left", "margin":"auto", "font-size":"12px"}},"table":{"class":"arraytop","style":"width:60%; height:60%; margin:auto; border-spacing: 10px 10px;"},"td":{"class":"classtd","style":"font-size:50px"},"type":"noeud","nodeid":[]}'
WHERE NOT EXISTS ( SELECT block_id FROM report_block WHERE block_name = 'REPORT_VALUE_SERVICE_NODE');

INSERT INTO report_block(block_name, block_controller, block_default_parameter)
SELECT 'REPORT_VALUE_SERVICE_SERVICE', 'value_service.php', '{"title":{"text":"Valeur de services","style":{"text-align":"left", "font-size":"15px", "color":"#575759"}},"description":{"text":"Voici la valeur des services","style":{"text-align":"left", "margin":"auto", "font-size":"12px"}},"table":{"class":"arraytop","style":"width:60%; height:60%; margin:auto; border-spacing: 10px 10px;"},"td":{"class":"classtd","style":"font-size:50px"},"type":"service","serviceid":[],"nodeid":[]}'
WHERE NOT EXISTS ( SELECT block_id FROM report_block WHERE block_name = 'REPORT_VALUE_SERVICE_SERVICE');

INSERT INTO report_block(block_name, block_controller, block_default_parameter)
SELECT 'REPORT_VALUE_SERVICE_GROUP_NODE', 'value_service.php','{"title":{"text":"Valeur de services","style":{"text-align":"left", "font-size":"15px", "color":"#575759"}},"description":{"text":"Voici la valeur des services","style":{"text-align":"left", "margin":"auto", "font-size":"12px"}},"table":{"class":"arraytop","style":"width:60%; height:60%; margin:auto; border-spacing: 10px 10px;"},"td":{"class":"classtd","style":"font-size:50px"},"type":"groupenoeud","serviceid":[],"groupnodeid":[]}'
WHERE NOT EXISTS ( SELECT block_id FROM report_block WHERE block_name = 'REPORT_VALUE_SERVICE_GROUP_NODE');

INSERT INTO report_block(block_name, block_controller, block_default_parameter)
SELECT 'REPORT_VALUE_PLUGIN_GROUP_NODE', 'value_service.php','{"title":{"text":"Valeur de services","style":{"text-align":"left", "font-size":"15px", "color":"#575759"}},"description":{"text":"Voici la valeur des services","style":{"text-align":"left", "margin":"auto", "font-size":"12px"}},"table":{"class":"arraytop","style":"width:60%; height:60%; margin:auto; border-spacing: 10px 10px;"},"td":{"class":"classtd","style":"font-size:50px"},"type":"groupenoeudplugin","serviceid":[],"groupnodeid":[]}'
WHERE NOT EXISTS ( SELECT block_id FROM report_block WHERE block_name = 'REPORT_VALUE_PLUGIN_GROUP_NODE');

INSERT INTO report_block(block_name, block_controller, block_default_parameter)
VALUES ('REPORT_GPDR_LOG', 'block_gpdr.php', '{"title":{"text":"Log RGPD","style":{"text-align":"left", "font-size":"15px", "color":"#575759"}},"description":{"text":"Voici le registre RGPD","style":{"text-align":"left", "margin":"auto", "font-size":"12px"}},"table":{"class":"arraytop","style":"width:60%; height:60%; margin:auto; border-spacing: 10px 10px;"},"td":{"class":"classtd","style":"font-size:50px"}}')
ON CONFLICT (block_name) DO NOTHING;

INSERT INTO report_block(
            block_name, block_controller, block_default_parameter)
    VALUES ('REPORT_SERVICE_INCIDENT', 'incident.php', '{"title":{"text":"Incident","style":{"text-align":"left", "font-size":"15px", "color":"#575759"}},"description":{"text":"Voici la description d''un incident","style":{"text-align":"left", "margin":"auto", "font-size":"12px"}},"table":{"class":"arraytop","style":"width:60%; height:60%; margin:auto; border-spacing: 10px 10px;"},"td":{"class":"classtd","style":"font-size:50px"},"type":"service","affiche_duree":true,"affiche_ip":true,"affiche_groupNoeud":true,"affiche_message":true,"serviceid":[]}'),
    ('REPORT_SERVICE_AVAILABILITY', 'availability.php', '{"title":{"text":"Disponibilité","style":{"text-align":"left", "font-size":"15px", "color":"#575759"}},"description":{"text":"Voici la description disponibilité d''un service","style":{"text-align":"left", "margin":"auto", "font-size":"12px"}},"table":{"class":"arraytop","style":"width:60%; height:60%; margin:auto; border-spacing: 10px 10px;"},"td":{"class":"classtd","style":"font-size:50px"},"SeuilWarning":"80","SeuilCritical":"70","forme":"graph","type":"service","serviceid":[]}'),
    ('REPORT_SERVICE_GRAPH', 'graphique.php', '{"title":{"text":"Graphique","style":{"text-align":"left","font-size":"25px","color":"#38f70a"}},"description":{"text":"Voici la description Graphique","style":{"text-align":"left","margin":"auto","font-size":"15px"}},"table":{"class":"arraytop","style":"width:60%; height:60%; margin:auto; border-spacing: 10px 10px;"},"td":{"class":"classtd","style":"font-size:50px"},"type":"service","nodeid":[],"serviceid":[]}'),
    ('REPORT_NODE_AVAILABILITY', 'availability.php', '{"title":{"text":"Disponibilité","style":{"text-align":"left", "font-size":"15px", "color":"#575759"}},"description":{"text":"Voici la description disponibilité d''un noeud","style":{"text-align":"left", "margin":"auto", "font-size":"12px"}},"table":{"class":"arraytop","style":"width:60%; height:60%; margin:auto; border-spacing: 10px 10px;"},"td":{"class":"classtd","style":"font-size:50px"},"SeuilWarning":"80","SeuilCritical":"70","forme":"graph","type":"noeud","nodeid":[]}'),
    ('REPORT_BLOCK_TEXT', 'textBlock.php', '{"title":{"text":"Texte","style":{"text-align":"left", "font-size":"15px", "color":"#575759"}},"description":{"text":"Voici la description text","style":{"text-align":"left", "margin":"auto", "font-size":"12px"}},"table":{"class":"arraytop","style":"width:60%; height:60%; margin:auto; border-spacing: 10px 10px;"},"td":{"class":"classtd","style":"font-size:50px"}}'),
    ('REPORT_NODE_INCIDENT', 'incident.php', '{"title":{"text":"Incident","style":{"text-align":"left", "font-size":"15px", "color":"#575759"}},"description":{"text":"Voici la description d''un incident","style":{"text-align":"left", "margin":"auto", "font-size":"12px"}},"table":{"class":"arraytop","style":"width:60%; height:60%; margin:auto; border-spacing: 10px 10px;"},"td":{"class":"classtd","style":"font-size:50px"},"type":"noeud","affiche_duree":true,"affiche_ip":true,"affiche_groupNoeud":true,"affiche_message":true,"nodeid":[]}')
ON CONFLICT (block_name) DO NOTHING;

--- REPORT  3.0_to_3.0.10 (Correction color titre block graph)
UPDATE report_block
   SET block_default_parameter='{"title":{"text":"Graphique","style":{"text-align":"left","font-size":"25px","color":"#575759"}},"description":{"text":"Voici la description Graphique","style":{"text-align":"left","margin":"auto","font-size":"15px"}},"table":{"class":"arraytop","style":"width:60%; height:60%; margin:auto; border-spacing: 10px 10px;"},"td":{"class":"classtd","style":"font-size:50px"},"type":"service","nodeid":[],"serviceid":[]}'
 WHERE block_controller='graphique.php';

--- REPORT  3.0.10_to_3.0.12 (Correction size titre block graph)
UPDATE report_block
   SET block_default_parameter='{"title":{"text":"Graphique","style":{"text-align":"left","font-size":"15px","color":"#575759"}},"description":{"text":"Voici la description Graphique","style":{"text-align":"left","margin":"auto","font-size":"15px"}},"table":{"class":"arraytop","style":"width:60%; height:60%; margin:auto; border-spacing: 10px 10px;"},"td":{"class":"classtd","style":"font-size:50px"},"type":"service","nodeid":[],"serviceid":[]}'
 WHERE block_controller='graphique.php';

---- REPORT (MAJ parameter graphique)
UPDATE report_block
   SET block_default_parameter='{"title":{"text":"Graphique","style":{"text-align":"left","font-size":"15px","color":"#575759"}},"description":{"text":"Voici la description Graphique","style":{"text-align":"left","margin":"auto","font-size":"12px"}},"table":{"class":"arraytop","style":"width:60%; height:60%; margin:auto; border-spacing: 10px 10px;"},"td":{"class":"classtd","style":"font-size:50px"},"type":"service","nodeid":[],"serviceid":[]}'
  WHERE block_name='REPORT_SERVICE_GRAPH';

---- REPORT (Maj BD pour choisir le niveau d'alerte dans incident)
UPDATE report_block
   SET block_default_parameter='{"title":{"text":"Incident","style":{"text-align":"left", "font-size":"15px", "color":"#575759"}},"description":{"text":"Voici la description incident","style":{"text-align":"left", "margin":"auto", "font-size":"12px"}},"table":{"class":"arraytop","style":"width:60%; height:60%; margin:auto; border-spacing: 10px 10px;"},"td":{"class":"classtd","style":"font-size:50px"},"type":"noeud","affiche_duree":true,"affiche_ip":true,"affiche_groupNoeud":true,"affiche_message":true,"nodeid":[]}'
 WHERE block_name='REPORT_NODE_INCIDENT';

UPDATE report_block
   SET block_default_parameter='{"title":{"text":"Incident","style":{"text-align":"left", "font-size":"15px", "color":"#575759"}},"description":{"text":"Voici la description incident","style":{"text-align":"left", "margin":"auto", "font-size":"12px"}},"table":{"class":"arraytop","style":"width:60%; height:60%; margin:auto; border-spacing: 10px 10px;"},"td":{"class":"classtd","style":"font-size:50px"},"type":"groupenoeud","affiche_duree":true,"affiche_ip":true,"affiche_groupNoeud":true,"affiche_message":true,"affiche_unknown":true,"affiche_warning":true,"affiche_critical":true,"groupnodeid":[]}'
 WHERE block_name='REPORT_INCIDENT_GROUP_NODE';

UPDATE report_block
   SET block_default_parameter='{"title":{"text":"Incident","style":{"text-align":"left", "font-size":"15px", "color":"#575759"}},"description":{"text":"Voici la description incident","style":{"text-align":"left", "margin":"auto", "font-size":"12px"}},"table":{"class":"arraytop","style":"width:60%; height:60%; margin:auto; border-spacing: 10px 10px;"},"td":{"class":"classtd","style":"font-size:50px"},"type":"service","affiche_duree":true,"affiche_ip":true,"affiche_groupNoeud":true,"affiche_message":true,"affiche_unknown":true,"affiche_warning":true,"affiche_critical":true,"serviceid":[]}'
 WHERE block_name='REPORT_SERVICE_INCIDENT';

--- REPORT 3.1.0_to_3.1.1
UPDATE report_block
   SET block_default_parameter='{"title":{"text":"Incident","style":{"text-align":"left", "font-size":"15px", "color":"#575759"}},"description":{"text":"Voici la description incident","style":{"text-align":"left", "margin":"auto", "font-size":"12px"}},"table":{"class":"arraytop","style":"width:60%; height:60%; margin:auto; border-spacing: 10px 10px;"},"td":{"class":"classtd","style":"font-size:50px"},"type":"noeud","affiche_duree":true,"affiche_ip":true,"affiche_groupNoeud":true,"affiche_message":true,"affiche_unknown":true,"affiche_warning":true,"affiche_critical":true,"nodeid":[]}'
 WHERE block_name='REPORT_NODE_INCIDENT';

--WEBPLUGIN
INSERT INTO esia_privilege_grantedto VALUES ((SELECT group_id FROM esia_groups WHERE group_name='root'),(SELECT privilege_id FROM esia_privileges WHERE privilege_name='report_canevas'),1)
ON CONFLICT (grant_group_id, grant_privilege_id) DO NOTHING;
INSERT INTO esia_privilege_grantedto VALUES ((SELECT group_id FROM esia_groups WHERE group_name='root'),(SELECT privilege_id FROM esia_privileges WHERE privilege_name='report_administration_mail'),1)
ON CONFLICT (grant_group_id, grant_privilege_id) DO NOTHING;

INSERT INTO esia_web_plugin(web_name, web_dir_lang, web_index_page,web_activate, web_tpl_method, web_plugin_apache_path,web_show_main_menu, web_icon)
VALUES ('WEBP_REPORT','lang/','report_control.php',TRUE,'universal','/plugin/report/',TRUE,'/plugin/report/images/menu_report.png')
ON CONFLICT (web_name) DO NOTHING;
